# genotyphi_mykrobe

Implementation of the Genotyphi scheme into Mykrobe.

## Probe list
The following is the list of probes that Mykrobe screens for:
* invA (to detect Salmonella enterica)
* Typhi STs (as per the list in `probes/typhiSTs.txt`)
* Genotype (as per the defintions in `probes/typhi_lineage_positions.txt`)
* QRDR SNPs (as per the list in `probes/qrdr.acrB.aa.in.txt`)
* acrB SNPs (as per the list in `probes/qrdr.acrB.aa.in.txt`)
* AMR genes (as per the list in `probes/amr_genes_drugs.txt`, using sequences from `probes/CARD_AMR_v3.0.8_curated_Aug2020.fasta`)
* Plasmid replicons (as per the list in `probes/amr_genes_drugs.txt`, using sequences from `probes/PlasmidFinder_inclZ66.fasta`)
* pST check for IncHI1BR27 replicon -> returns 'resistant' if an ST6 plasmid, 'susceptible' otherwise (using position in `probes/pST_positions.txt` and genome `AM412236.fasta`)

## Probe creation
To create probes, Mykrobe must be installed, along with the python library `cluster_vcf_records` (can be found [here](https://github.com/iqbal-lab-org/cluster_vcf_records))

Inside directory `probes`, run the following:
`./make_probes.sh`

This will take all the inside `probes/vcfs_for_probe_creation` and generate a background VCF file, which is used to ensure all probes generated for genotype and QRDR/acrB SNPs have the appropriate background SNPs as required.

This script then runs various other scripts inside the `probes` directory to make each set of probes. These probes are then combined into a single tarball, with a manifest.json file that lists the details.

**A note on the pST probe**
Please note that the generation for this probe is weird. The reference plasmid for this probe is AM412236, which _carries the pST6 marker SNP, C19241A_. As a result, if we used the probes as they are generated by `mykrobe variants make-probes`, then this will return 'resistant' for all genomes that **do not** carry the pST6 SNP, and 'susceptible' for those that do, which is the opposite behaviour of what we want. Therefore there is an extra line in `make_probes.sh` that swaps the two probes around so we get the behaviour we desire.

This is a not ideal solution, but couldn't work out the corresponding position in an alternate reference for us to use, so this is what is implemented for now.

## Adding probe tarball to Mykrobe install
To add the probe tarball to Mykrobe, run the following commands:
```
mykrobe panels update_metadata --filename manifest_typhi_url.json
mykrobe panels update_species all
```

If you have done this in the past, you need first to remove the files that Mykrobe is using to check if the panel has been updated, eg:
```
rm -r ~/miniconda3/envs/mykrobe_typhi/lib/python3.9/site-packages/mykrobe/data/typhi
rm ~/miniconda3/envs/mykrobe_typhi/lib/python3.9/site-packages/mykrobe/data/manifest.json
```

## Species calls
All genomes are correctly being called as _Salmonella enterica_. I selected a random sample of non-Typhi genomes to test with Mykrobe. S. Typhi genomes have >89% coverage to the ST probes, with non Typhi genomes falling below that (or failing detection entirely). Therefore, the current cutoff for the parser is 89% for calling a genome as Typhi. [See here for results and figure](Rmarkdown/spp_check.html). We may need to adjust this threshold for ONT data in the future.

## Parser script
`parse_typhi_mykrobe.py` is the script used to create a table summarising the Mykrobe results. As input, it takes the json files (`--jsons`), and a prefix (`--prefix`) for the output files.

Explanation of columns in the output:
* **genome**: sample ID
* **species**: species call from Mykrobe (typhi or unknown; determined by matching to Typhi STs from the 7-locus MLST scheme)
* **spp_percent:** percentage coverage to the Typhi ST probes
* **final genotype**: final genotype call from Mykrobe, using the scheme currently implemented in Genotyphi.
* **confidence**: measure of confidence in the final genotype call, summarising read support across all levels in the hierarchy (lineage, clade, subclade, etc)
  * _strong_ - high quality calls (quality of '1' reported by Mykrobe) for ALL levels;
  * _moderate_ - reduced confidence for ONE node (Mykrobe quality of '0.5', but still with >50% read support for the marker allele), high quality calls for ALL OTHERS;
  * _weak_ - low quality for one or more nodes (Mykrobe quality of '0.5' and <50% read support OR Mykrobe quality of '0').
* **acrB_R717L, acrB_7171Q**: calls for individual acrB (azithromycin resistance) mutation. 0 indicates mutation is absent, 1 indicates mutation is present.
* **num QRDR**: Total number of mutations detected in the quinolone-resistance determining regions (QRDR) of genes _gyrA_, _parC_ and _gyrB_.
* **lowest support for genotype marker**: For any markers in the final genotype call that do not have a Mykrobe quality of '1', this column reports the percentage of reads supporting the marker allele at the most poorly supported marker (details of all such markers appear in the 'poorly supported markers column').
* **poorly supported markers**: Lists any markers in the final genotype call that do not have Mykrobe quality of '1'. Markers are separated by ';', values in brackets represent the quality call from Mykrobe, followed by the read depth at the alternate / reference alleles. The lowest read support amongst these markers is reported in the previous column.
* **max support for additional markers**: For any markers detected that are incongruent with the finall genotype call, this column reports the percentage of reads supporting the marker allele at the best supported additional marker.
* **additional markers**: Lists any markers that are incongruent with the final genotype call. Markers are separated by ';', and the format is identical to column _poorly supported markers_. The highest read support for any such marker is reported in the previous column.
* **node support**: A list of all markers in the final genotype call with their Mykrobe quality calls (1, 0.5, or 0) and the read depths at the marker allele / reference allele (as per _poorly supported markers_ and _additional markers_).
* **parC_S80R, parC_S80I, parC_E84G, parC_E84K, gyrA_S83F, gyrA_S83Y, gyrA_D87G, gyrA_D87N, gyrA_D87V, gyrA_D87Y, gyrB_S464F, gyrB_S464Y**: calls for each individual QRDR mutation. 0 indicates mutation is absent, 1 indicates mutation is present.
* **remaining columns** indicate presence (1) or absence (0) of each AMR gene or plasmid replicon as indicated by the header of the column. For AMR genes, specific alleles are not detected (with the exception of dfrA, where Mykrobe can distinguish between dfrA7, dfrA5 and dfrA15).
  * **IncHI1_ST6** indicates whether the IncHI1 replicon (from column IncHI1BR27) is pST6 (1) or not (0).
